@@ -1,6 +1,11 @@
+from glob import glob
+from pathlib import Path
+
 from ..utils.regex import strcompile
 from ..utils.urls import parse_curl
 
+
+
 class BaseAction:
 
     def __init__(self, **kwargs):
@@ -17,7 +22,6 @@ class BaseAction:
 
 
 
-
 class UrlRenderAction(BaseAction):
 
     def __init__(self, **kwargs):
@@ -28,6 +32,7 @@ class UrlRenderAction(BaseAction):
             )
 
 
+
 class UrlPatternAction(BaseAction):
 
     def __init__(self, **kwargs):
@@ -44,23 +49,22 @@ class UrlPatternAction(BaseAction):
 
 
 
-
-
-
-
 def urlrender(
     host=None, urlrenderer=None, headers=None, cookies=None,
-    payloader=None, parser=None, extractor=None, urlfilter=None, breaker=None, fields=None, contentfile=False, referer=None, name=None, refresh=False):
+    payloader=None, parser=None, extractor=None, urlfilter=None, breaker=None, fields=None, contentfile=False, referer=None, name=None, refresh=False, delay=None):
     return UrlRenderAction(**locals())
 
 
 def urlpattern(
     urlpattern=None, urlpattern_renderer=None, remove_duplicates=True, attrs=None, css_selector=None, recursive=False, headers=None, cookies=None,
-    payloader=None, parser=None, extractor=None, urlfilter=None, breaker=None, fields=None, contentfile=False, referer=None, name=None, refresh=False):
+    payloader=None, parser=None, extractor=None, urlfilter=None, breaker=None, fields=None, contentfile=False, referer=None, name=None, refresh=False, delay=None):
     return UrlPatternAction(**locals())
 
 
-def fromcurl(curl_template=None, payloader=None, urlrenderer=None, parser=None, name=None, headers=None, cookies=None, **kwargs):
+def fromcurl(curl_template=None, payloader=None, urlrenderer=None, parser=None, name=None, headers=None, cookies=None, remove_line='\n', **kwargs):
+    if remove_line:
+        curl_template = curl_template.replace(remove_line, '')
+        
     p = parse_curl(curl_template)
 
     def fromcurl_urlrenderer(url):
@@ -80,3 +84,21 @@ def fromcurl(curl_template=None, payloader=None, urlrenderer=None, parser=None,
     )
 
 
+def frompath(path, path_renderer=None, parser=None, name=None, refresh=True, delay=0, recursive=True, **kwargs):
+    def urlrenderer(url):
+        if url.startswith('file:///'):
+            yield url
+        
+        for p in glob(url, recursive=recursive):
+            p = Path(p).absolute().as_uri()
+            yield p   
+    
+    return urlrender(
+        host=path,
+        urlrenderer=path_renderer or urlrenderer,
+        parser=parser,
+        name=name,
+        refresh=refresh,
+        delay=delay,
+        **kwargs
+    )
\ No newline at end of file
