@@ -8,9 +8,11 @@ def strcompile(exp):
         return exp
 
 
-def extgroup(exp, target):
+def extgroup(exp, target, asdict=False):
     regex = strcompile(exp)
     if g := regex.search(target):
+        if asdict:
+            return g.groupdict()
         return g.group
     # raise ValueError(f"{exp} not matched on {target}")
 
