@@ -12,10 +12,8 @@ COUNT_PER_PAGE = 100
 config = {
     'REQUEST_CACHE_BACKEND': 'memory',
     'REQUEST_DELAY': (1, 1.5),
-    'PROXIES_LIST': [
-        {'https':'103.37.141.68:80'},
-        None
-    ]
+    'REQUESTS_TIMEOUT': 5
+
 }
 
 
